@@ -18,16 +18,12 @@ sys.path.append(_parent + "/site-packages.zip")
 # add the uncompressed site-packages to the path to compensate for that.
 sys.path.append(_parent + "/site-packages")
 
+ENABLE_USER_SITE = False
+
 USER_SITE = None
 USER_BASE = None
 
-
-def _import_os():
-    global os
-    import os  # noqa: E402
-
-
-_import_os()
+import os
 
 try:
     basestring
@@ -195,8 +191,14 @@ except ImportError:
 if hasattr(sys, "setdefaultencoding"):
     del sys.setdefaultencoding
 
-import builtins  # noqa: E402
+if sys.version_info[0] == 3:
+    import builtins  # noqa: E402
 
-import _sitebuiltins  # noqa: E402
+    import _sitebuiltins  # noqa: E402
 
-builtins.help = _sitebuiltins._Helper()
+    builtins.help = _sitebuiltins._Helper()
+    builtins.quit = _sitebuiltins.Quitter("quit", "Ctrl-D (i.e. EOF)")
+    builtins.exit = _sitebuiltins.Quitter("exit", "Ctrl-D (i.e. EOF)")
+
+# Prefixes for site-packages; add additional prefixes like /usr/local here
+PREFIXES = [sys.prefix, sys.exec_prefix]
