@@ -34,9 +34,8 @@ def check(cmd, mf):
         except ImportError:
             mf.import_hook("sip", m, level=1)
 
-
         qtdir = QLibraryInfo.location(QLibraryInfo.LibrariesPath)
-        if qtdir != os.path.dirname(PyQt5.__file__):
+        if os.path.relpath(qtdir, os.path.dirname(PyQt5.__file__)).startswith("../"):
             # Qt5's prefix is not the PyQt5 package, which means
             # the "packages" directive below won't include everything
             # needed, and in particular won't include the plugins
@@ -53,12 +52,15 @@ def check(cmd, mf):
             extra = {}
 
         if sys.version[0] != 2:
-            return {
+            result = {
                 "packages": ["PyQt5"],
                 "expected_missing_imports": {"copy_reg", "cStringIO", "StringIO"},
-                **extra,
             }
+            result.update(extra)
+            return result
         else:
-            return {"packages": ["PyQt5"], **extra}
+            result = {"packages": ["PyQt5"]}
+            result.update(extra)
+            return result
 
     return None
