@@ -25,7 +25,7 @@ def check(cmd, mf):
             return None
 
         qtdir = QLibraryInfo.path(QLibraryInfo.LibraryPath.LibrariesPath)
-        if qtdir != os.path.dirname(PyQt6.__file__):
+        if os.path.relpath(qtdir, os.path.dirname(PyQt6.__file__)).startswith("../"):
             # Qt6's prefix is not the PyQt6 package, which means
             # the "packages" directive below won't include everything
             # needed, and in particular won't include the plugins
@@ -35,7 +35,9 @@ def check(cmd, mf):
             # Ensure that the Qt plugins are copied into the "Contents/plugins" folder,
             # that's where the bundles Qt expects them to be
             extra = {
-                "resources": [("..", [QLibraryInfo.path(QLibraryInfo.LibraryPath.PluginsPath)])]
+                "resources": [
+                    ("..", [QLibraryInfo.path(QLibraryInfo.LibraryPath.PluginsPath)])
+                ]
             }
 
         else:
@@ -51,6 +53,8 @@ def check(cmd, mf):
         except ImportError:
             mf.import_hook("sip", m, level=1)
 
-        return {"packages": ["PyQt6"], **extra}
+        reslt = {"packages": ["PyQt6"]}
+        result.update(extra)
+        return result
 
     return None
